@@ -29,9 +29,7 @@ typedef enum {
 
 gint folderutils_delete_duplicates(FolderItem *item,
 				   DeleteDuplicatesMode mode);
-void folderutils_mark_all_read	  (FolderItem *item);
-void folderutils_mark_all_unread	  (FolderItem *item);
-void folderutils_mark_all_read_recursive	  (FolderItem *item);
-void folderutils_mark_all_unread_recursive	  (FolderItem *item);
+void folderutils_mark_all_read	  (FolderItem *item, gboolean read);
+void folderutils_mark_all_read_recursive	  (FolderItem *item, gboolean read);
 
 #endif /* FOLDERUTILS_H */
